Module ipc

Module ipc 

IPC helpers for communicating with the resident supervisor.

Structs

InspectPayload
Inspect response payload.

Enums

ControlCommand
Message sent from CLI invocations to the resident supervisor.
ControlError
Errors raised by the control channel helpers.
ControlResponse
Response sent by the supervisor.

Functions

cleanup_runtime
Clears the supervisor PID and removes the socket file.
read_command
Utility to read a command from a UnixStream. Used by the supervisor event loop.
read_config_hint
Reads the persisted config path hint if available.
read_supervisor_pid
Reads the supervisor PID if present.
send_command
Sends a command to the supervisor and waits for a response.
socket_path
Returns the unix socket path used to communicate with the resident supervisor.
supervisor_pid_path
Returns the path where the supervisor PID is recorded.
write_config_hint
Persists the resolved config path to assist CLI fallbacks.
write_response
Writes a response to the connected CLI client.
write_supervisor_pid
Persists the supervisor PID for later CLI detection.