IPC helpers for communicating with the resident supervisor.
Structs
- Inspect
Payload - Inspect response payload.
Enums
- Control
Command - Message sent from CLI invocations to the resident supervisor.
- Control
Error - Errors raised by the control channel helpers.
- Control
Response - Response sent by the supervisor.
Functions
- cleanup_
runtime - Clears the supervisor PID and removes the socket file.
- read_
command - Utility to read a command from a
UnixStream. Used by the supervisor event loop. - read_
config_ hint - Reads the persisted config path hint if available.
- read_
supervisor_ pid - Reads the supervisor PID if present.
- send_
command - Sends a command to the supervisor and waits for a response.
- socket_
path - Returns the unix socket path used to communicate with the resident supervisor.
- supervisor_
pid_ path - Returns the path where the supervisor PID is recorded.
- write_
config_ hint - Persists the resolved config path to assist CLI fallbacks.
- write_
response - Writes a response to the connected CLI client.
- write_
supervisor_ pid - Persists the supervisor PID for later CLI detection.